<?php

namespace Aeneria\GrdfAdictApi\Service;

use Aeneria\GrdfAdictApi\Model\ConsentementDetail;
use Aeneria\GrdfAdictApi\Model\Token;

/**
 * Implements GRDF adict authentification API
 *
 * @see https://site.grdf.fr/web/grdf-adict/technique/
 */
interface AuthentificationServiceInterface
{
    /**
     * Get a URL to GRDF adict consent page.
     *
     * @var string Paramètre de sécurité permettant de maintenir l’état
     * entre la requête et la redirection.
     *
     * @var string Nom de l'organisation qui demande le consentement.
     * Utilisé pour identifier visuellement l'organisation sur le site de GRDF.
     *
     * @var string Paramètre pour préremplire le formulaire de consentement
     *
     * @var string Paramètre pour préremplire le formulaire de consentement
     *
     * @var string Paramètre pour préremplire le formulaire de consentement
     */
    public function getConsentPageUrl(string $state, string $organisationName, string $firstnameHint = 'Prénom', string $lastnameHint = 'Nom', string $emailHint = 'Email'): string;

    /**
     * Get Consentement Details from a grant code.
     */
    public function requestConsentementDetail(string $code): ConsentementDetail;

    /**
     * Get Authorization Token from credentials.
     */
    public function requestAuthorizationToken(): Token;
}
